@@ -1,13 +1,10 @@
 package Kwiki::Search;
-use strict;
-use warnings;
-use Kwiki::Plugin '-Base';
+use Kwiki::Plugin -Base;
 use mixin 'Kwiki::Installer';
 use Kwiki ':char_classes';
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 
 const class_id => 'search';
-const class_title => 'Search';
 const cgi_class => 'Kwiki::Search::CGI';
 const css_file => 'search.css';
 
@@ -25,7 +22,7 @@ sub search {
     my $num = @$pages;
     my $screen_title = length($term)
     ? "$num Pages Matching '$term'"
-    : 'All Pages';
+    : "All $num Pages";
     $self->render_screen(
         screen_title => $screen_title,
         pages => $pages,
@@ -37,18 +34,17 @@ sub perform_search {
     $search =~ s/[^$WORD\ \-\.\^\$\*\|\:]//g;
     [ 
         grep {
-            $_->content =~ m{$search}i and 
-            $_->active
+            ($_->id =~ m{$search}i ||
+             $_->content =~ m{$search}i
+            ) and $_->active
         } $self->pages->all 
     ]
 }
 
 package Kwiki::Search::CGI;
-use Kwiki::CGI '-base';
+use Kwiki::CGI -base;
 
-cgi search_term => '-utf8';
-
-1;
+cgi search_term => -utf8;
 
 package Kwiki::Search;
 __DATA__
@@ -76,24 +72,20 @@ See http://www.perl.com/perl/misc/Artistic.html
 
 =cut
 __template/tt2/search_box.html__
-<!-- BEGIN search_box.html -->
 <form method="post" action="[% script_name %]" enctype="application/x-www-form-urlencoded" style="display: inline">
 <input type="text" name="search_term" size="8" value="Search" onfocus="this.value=''" />
 <input type="hidden" name="action" value="search" />
 </form>
-<!-- END search_box.html -->
 __template/tt2/search_content.html__
-<!-- BEGIN search_content.html -->
 <table class="search">
 [% FOR page = pages %]
 <tr>
-<td class="page_id">[% page.kwiki_link %]</td>
+<td class="page_name">[% page.kwiki_link %]</td>
 <td class="edit_by">[% page.edit_by_link %]</td>
 <td class="edit_time">[% page.edit_time %]</td>
 </tr>
 [% END %]
 </table>
-<!-- END search_content.html -->
 __css/search.css__
 table.search {
     width: 100%;
@@ -104,7 +96,7 @@ table.search td {
     padding: .2em 1em .2em 1em;
 }
 
-table.search td.page_id   { 
+table.search td.page_name   { 
     text-align: left;
 }
 table.search td.edit_by   { 
